@@ -5,12 +5,12 @@ use utf8;
 
 # ABSTRACT: Values for MARC21 based on RDA
 
-our $VERSION = '1.001'; # VERSION
+our $VERSION = '1.002'; # VERSION
 
 use Koha::Contrib::ValueBuilder::RepeatableAutocomplete;
 use Exporter 'import';
 
-our @EXPORT_OK = qw(f100 f700);
+our @EXPORT_OK = qw(creator other_agent);
 
 sub creator {
     my $lang = lc(shift) || 'de';
@@ -214,7 +214,7 @@ Koha::Contrib::ValueBuilder::RepeatableAutocomplete::RDA - Values for MARC21 bas
 
 =head1 VERSION
 
-version 1.001
+version 1.002
 
 =head1 SYNOPSIS
 
